summaryrefslogtreecommitdiffstats
path: root/pkgs/applications/audio
diff options
context:
space:
mode:
authorFrederik Rietdijk <fridh@fridh.nl>2021-01-07 09:13:02 +0100
committerFrederik Rietdijk <fridh@fridh.nl>2021-01-07 09:13:16 +0100
commit479867700baa7ced259c979a0f724915c4d46d12 (patch)
treec561a1c4d1e4e6f3fbe00db6d9433def5e16ff36 /pkgs/applications/audio
parent90d4109c23da03daeb7dece49f7f16492ae3d96c (diff)
ecasound: let it use more dependencies
Patch partially contributed by Kai Ruemmler.
Diffstat (limited to 'pkgs/applications/audio')
-rw-r--r--pkgs/applications/audio/ecasound/default.nix37
1 files changed, 35 insertions, 2 deletions
diff --git a/pkgs/applications/audio/ecasound/default.nix b/pkgs/applications/audio/ecasound/default.nix
index adb6f6b74274..505e5a604ca2 100644
--- a/pkgs/applications/audio/ecasound/default.nix
+++ b/pkgs/applications/audio/ecasound/default.nix
@@ -1,5 +1,6 @@
{ stdenv
, fetchurl
+, pkg-config
, alsaLib
, audiofile
, libjack2
@@ -9,9 +10,14 @@
, libsndfile
, lilv
, lv2
+, ncurses
+, readline
}:
# TODO: fix readline, ncurses, lilv, liblo, liboil and python. See configure log.
stdenv.mkDerivation rec {
pname = "ecasound";
@@ -22,7 +28,34 @@ stdenv.mkDerivation rec {
sha256 = "1m7njfjdb7sqf0lhgc4swihgdr4snkg8v02wcly08wb5ar2fr2s6";
};
- buildInputs = [ alsaLib audiofile libjack2 liblo liboil libsamplerate libsndfile lilv lv2 ];
+ nativeBuildInputs = [
+ pkg-config
+ ];
+
+ buildInputs = [
+ alsaLib
+ audiofile
+ libjack2
+ liblo
+ liboil
+ libsamplerate
+ libsndfile
+ lilv
+ lv2
+ ncurses
+ readline
+ ];
+
+ strictDeps = true;
+
+ configureFlags = "--enable-liblilv --with-extra-cppflags=-Dnullptr=0";
+
+ postPatch = ''
+ sed -i -e '
+ s@^#include <readline.h>@#include <readline/readline.h>@
+ s@^#include <history.h>@#include <readline/history.h>@
+ ' ecasound/eca-curses.cpp
+ '';
meta = {
description = "Software package designed for multitrack audio processing";
@@ -9,9 +10,14 @@
}:
-# TODO: fix readline, ncurses, lilv, liblo, liboil and python. See configure log.
+# TODO: fix python. See configure log.
+# fix -Dnullptr=0 cludge below.
+# The error is
+# /nix/store/*-lilv-0.24.10/include/lilv-0/lilv/lilvmm.hpp:272:53: error: 'nullptr' was not declared in this scope
stdenv.mkDerivation rec {
pname = "ecasound";